#
# spec file for package libxspf
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libxspf
Version:        1.2.1
Release:        1.9
Summary:        Provides XSPF playlist reading and writing support
License:        BSD-3-Clause AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://libspiff.sourceforge.net/
Source:         https://downloads.sourceforge.net/libspiff/Sources/%{version}/libxspf-%{version}.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libexpat-devel
BuildRequires:  libtool
BuildRequires:  liburiparser-devel >= 0.7.5
BuildRequires:  pkgconfig

%description
libxspf the replacement for libSpiff brings XSPF playlist reading and
 writing support to your C++ application. Both version 0 and 1 are
supported. libxspf uses Expat for XML parsing and CppTest for unit
testing. libxspf is the official reference implementation for XSPF
of the Xiph.Org Foundation. Features :-
* Full conformance to the XSPF specification
* Cross-platform (Unix, Windows, Mac OS X, ...)
* Read and write XSPF files
* XSPF-0 and XSPF-1 support
* Unicode support
* Full support for XSPF extensions
* Full support for XML namespaces
* Fast (XML parsing is done by Expat)
* Uses unit testing
* Liberal license: New BSD license

%package -n 	libxspf4
Summary:        Provides XSPF playlist reading and writing support
Group:          Development/Libraries/C and C++

%description -n libxspf4
libxspf brings XSPF playlist reading and writing support to your C++
application. Both version 0 and 1 are supported. libxspf uses Expat
for XML parsing and CppTest for unit testing. libxspf is the official
reference implementation for XSPF of the Xiph.Org Foundation. Features
* Full conformance to the XSPF specification
* Cross-platform (Unix, Windows, Mac OS X, ...)
* Read and write XSPF files
* XSPF-0 and XSPF-1 support
* Unicode support
* Full support for XSPF extensions
* Full support for XML namespaces
* Fast (XML parsing is done by Expat)
* Uses unit testing
* Liberal license: New BSD license

%package -n libxspf-devel
Summary:        Brings XSPF playlist read and write support to C++ apps
Group:          Development/Libraries/C and C++
Requires:       libexpat-devel
Requires:       libstdc++-devel
Requires:       libxspf4 = %{version}

%description -n libxspf-devel
libxspf brings XSPF playlist reading and writing support to your C++
application. Both version 0 and 1 are supported. libxspf uses Expat
for XML parsing and CppTest for unit testing. libxspf is the official
reference implementation for XSPF of the Xiph.Org Foundation. Features

* Full conformance to the XSPF specification

* Cross-platform (Unix, Windows, Mac OS X, ...)

* Read and write XSPF files

* XSPF-0 and XSPF-1 support

* Unicode support

* Full support for XSPF extensions

* Full support for XML namespaces

* Fast (XML parsing is done by Expat)

* Uses unit testing

* Liberal license: New BSD license

%prep
%setup -q

%build
autoreconf -fiv
%configure  \
  --disable-test \
  --enable-static=no \
  --with-pic
#  --enable-doc
%make_build

# This section no longer works without libcpptest and can be enabled when the package is available
# %check
# make %{?_smp_mflags} check

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libxspf4 -p /sbin/ldconfig
%postun -n libxspf4 -p /sbin/ldconfig

%files -n libxspf4
%{_libdir}/libxspf.so.4*

%files -n libxspf-devel
%{_bindir}/xspf_check
%{_bindir}/xspf_strip
%dir %{_includedir}/xspf
%dir %{_includedir}/xspf/ProjectOpus
%{_includedir}/xspf/ProjectOpus/*.h
%{_includedir}/xspf/*.h
%{_libdir}/libxspf.so
%{_libdir}/pkgconfig/xspf.pc

%changelog
* Sun Apr 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * Fixed: GCC 4.4 test suite compilation
  * Fixed: Missing unistd.h include in
  * Fixed: Compile errors when uriparser is located in a
    non-standard path that is passed to configure through
    variable PKG_CONFIG_PATH
  * Fixed: Update the GNU Autotools build system
    so that ./autogen.sh runs without warnings
  * Fixed: Allow linking with LLD
  * Improved: Modernize the GNU Autotools build system
  * Soname: 4:3:0 (please see https://verbump.de/
    for what these numbers do)
- drop libxspf-1.1.0-gcc44.patch libxspf-automake.diff libxspf-gcc47.patch
  (obsolete)
* Thu Nov 26 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update dependencies
* Sat Mar  2 2013 coolo@suse.com
- update license to new format
* Mon Jul 30 2012 crrodriguez@opensuse.org
- Fix build with as-needed and fix extra autotools bugs.
* Tue May 29 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
- Replace outdated constructs in configure.ac/Makefile.am to
  have the build succeed again
* Wed Mar 21 2012 dimstar@opensuse.org
- Add libxspf-gcc47.patch: Fix build with gcc 4.7.
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Apr 18 2010 davejplater@gmail.com
- Update to version 1.2.0 disabled make check due to missing cpptest
  which is needed for it.
- Upstream changes :-
  * Added: xspf_parse_memory function to C bindings
    exposing XspfReader::parseMemory
  * Changed: No longer shipping bundled libcpptest
  * Changed: New dependencies:
  - libcpptest 1.1.0 or later
  - uriparser 0.7.5 or later
  - pkg-config
    The libcpptest dependency can be disabled through
    configuring with --disable-test, which excludes the
    test suite from compilation.
  * Fixed: Doc generation bugs
  * Fixed: Qt Compressed Help files were not installed
  * Fixed: Shadow/VPATH build doc generation
* Wed May  6 2009 coolo@suse.de
- fix compilation with gcc 44
* Thu Feb 26 2009 crrodriguez@suse.de
- correct wrong -evel package requires
* Sun Feb 22 2009 crrodriguez@suse.de
- upstream rename to libxspf
- update to version 1.1.0
- added pkgconfig file
- fix compilation errors with gcc 43 and 44
* Fri Aug 22 2008 crrodriguez@suse.de
- add missing libexpat-devel  to -devel package
* Thu Jul 31 2008 crrodriguez@suse.de
- update to version 0.8.4
  * Fixed: Support for 'xml:base' attribute added
  * Fixed: Test suite compile fix for GCC 4.3
    Thanks to Samuli Suominen for the patch!
  * Changed: Code::Blocks project files updated from file format
    version 1.4 to 1.6, which is produced by Code::Blocks 8.02
  * Added: Code::Blocks workspace file
  * Fixed: Bundled Win32 CppTest updated to 1.1.0
  * Fixed: Bundled Win32 uriparser updated to 0.7.1
  * Soname: 1:4:0
* Sat Mar  8 2008 crrodriguez@suse.de
- version 0.8.3
  * Fixed: No more compile errors from GCC 4.3 (#1815520)
    Thanks to Cristian Rodriguez for the patch!
  * Added: Version guards for Autoconf/Automake
    Thanks to Martin Michlmayr for reporting!
  * Fixed: Compile error on Windows caused by out-of-date
    file lists
  * Fixed: Bundled Win32 uriparser updated to 0.6.4
  * Soname: 1:3:0
* Tue Feb  5 2008 crrodriguez@suse.de
- initial version for openSUSE 11, merge from OBS
* Thu Oct 18 2007 crrodriguez@suse.de
- update to version 0.8.2 , soname changed, now libspiff1
